@@ -1843,35 +1843,36 @@ GSList* gok_spy_append_node (GSList* nodes,
 			} while ((j < 3) && len);
 			AccessibleText_unref (text);
 		}
-		if (g_utf8_validate (gs, -1, NULL) &&
-		  g_utf8_strchr(gs,-1,GECKO_EMBEDDED_OBJECT_CHAR)){
-			/* We probably have a complex document, where text can contain 
-			utf-8 embed characters to denote the presence of an object 
-			within a region of text. (see mozilla a11y docs). We can safely
-			ignore this node as we capture the children denoted by the embeds
-			elsewhere. */
-			g_free(gs);
-		}
-		else {
-			if (gs && strlen (gs)) {
+		if (gs && strlen (gs)) {
+			if (gs && g_utf8_validate (gs, -1, NULL) &&
+		  		g_utf8_strchr(gs,-1,GECKO_EMBEDDED_OBJECT_CHAR)){
+				/* We probably have a complex document, where text can contain 
+				utf-8 embed characters to denote the presence of an object 
+				within a region of text. (see mozilla a11y docs). We can safely
+				ignore this node as we capture the children denoted by the embeds
+				elsewhere. */
+				g_free(gs);
+			}
+			else {
 				pName = g_strconcat (gs, "...", NULL);
 				g_free (gs);
 			}
-			else {
-				if (gs) {
-					g_free (gs);
-				}
-				if (Accessible_isEditableText (pAccessible)) {
-					pName = g_strdup ("Text Entry (empty)");
-				}
+		}
+		else {
+			if (gs) {
+				g_free (gs);
 			}
-			if (pName != NULL) {
-					if (*g_strstrip (pName) == 0 || strlen (pName) == 0) 
-					g_warning ("EMPTY Node name: [%s]", pName);
-				gok_log ("we have a name: [%s]",pName);
-				nodes = gok_spy_add_node (nodes, pAccessible, flags, 0, pName);
+			if (Accessible_isEditableText (pAccessible)) {
+				pName = g_strdup ("Text Entry (empty)");
 			}
 		}
+		if (pName != NULL) {
+			if (*g_strstrip (pName) == 0 || strlen (pName) == 0) 
+				g_warning ("EMPTY Node name: [%s]", pName);
+
+			gok_log ("we have a name: [%s]",pName);
+			nodes = gok_spy_add_node (nodes, pAccessible, flags, 0, pName);
+		}
 	}
 
 	/* use row and column info inside a table */
