@@ -165,7 +165,7 @@ utf8_wordcomplete_open (GokWordComplete *complete, const gchar *directory)
 	/* create gunichar hash for looking up search entry points */
 	utf8_wordcomplete_create_unicode_hash (utf8_complete);
 
-	fprintf (stderr, "Word prediction dictionary contains a total of %d words\n", 
+	gok_log ("Word prediction dictionary contains a total of %d words\n", 
 		 g_list_length (utf8_complete->word_list));
 
 	return TRUE;
